@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-__version__ = "0.5.2"
+__version__ = "0.5.3"
 __useragent__ = ('ldtools-%s (http://github.com/dmr/ldtools, daniel@nwebs.de)'
                  % __version__)
 
@@ -87,13 +87,10 @@ class RestBackend(AbstractBackend):
             "text/plain": "application/rdf+xml"
         }
 
-        print "backend",self.content_type
-
         if self.content_type in content_type_mapping:
             self.content_type = content_type_mapping[self.content_type]
 
         file_extension = mimetypes.guess_extension(self.content_type)
-        print file_extension
         if file_extension:
             format = file_extension.strip(".")
             if format in ["rdf", "ksh"]:
